.. Quantum Information Toolkit documentation master file

Quantum Information Toolkit
===========================

:Release: |release|
:Date: |today|

Contents:

.. toctree::
   :maxdepth: 1

   utils
   lmap
   state
   gate
   hamiltonian
   ho
   invariant
   markov
   seq
   examples
   references

.. include:: ../README.txt
   :start-line: 4


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
